@@ -92,6 +92,12 @@ def setup_grade_file_report(ReportClass, execute=False, obfuscate=False, minify=
                                                        'head': pyhead})
     output = fn[:-3] + "_grade.py"
     print("> Writing student script to", output, "(this script may be shared)")
+    # Add the relative location string:
+
+    # Add relative location to first line of file. Important for evaluation/sanity-checking.
+    report_relative_dir = report._import_base_relative()[1]
+    s = "# " + report_relative_dir + "\n" + s
+
     with open(output, 'w', encoding="utf-8") as f:
         f.write(s)
 
@@ -114,6 +120,7 @@ def setup_grade_file_report(ReportClass, execute=False, obfuscate=False, minify=
         wa = """ WARNING: Modifying, decompiling or otherwise tampering with this script, it's data or the resulting .token file will be investigated as a cheating attempt. """
         sauce = ["'''" + wa + "'''"] + sauce[:-1]
         sauce = "\n".join(sauce)
+        sauce = "# " + report_relative_dir + "\n" + sauce
         with open(output, 'w') as f:
             f.write(sauce)
 
